@@ -2,7 +2,7 @@
 // stream_descriptor.cpp
 // ~~~~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2020 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2022 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -68,6 +68,9 @@ void test()
 
 #if defined(ASIO_HAS_MOVE)
     posix::stream_descriptor descriptor5(std::move(descriptor2));
+
+    posix::basic_stream_descriptor<io_context::executor_type> descriptor6(ioc);
+    posix::stream_descriptor descriptor7(std::move(descriptor6));
 #endif // defined(ASIO_HAS_MOVE)
 
     // basic_stream_descriptor operators.
@@ -75,6 +78,7 @@ void test()
 #if defined(ASIO_HAS_MOVE)
     descriptor1 = posix::stream_descriptor(ioc);
     descriptor1 = std::move(descriptor2);
+    descriptor1 = std::move(descriptor6);
 #endif // defined(ASIO_HAS_MOVE)
 
     // basic_io_object functions.
@@ -88,9 +92,9 @@ void test()
       = descriptor1.lowest_layer();
     (void)lowest_layer;
 
-    const posix::stream_descriptor& descriptor6 = descriptor1;
+    const posix::stream_descriptor& descriptor8 = descriptor1;
     const posix::stream_descriptor::lowest_layer_type& lowest_layer2
-      = descriptor6.lowest_layer();
+      = descriptor8.lowest_layer();
     (void)lowest_layer2;
 
     int native_descriptor2 = -1;
@@ -179,5 +183,5 @@ void test()
 ASIO_TEST_SUITE
 (
   "posix/stream_descriptor",
-  ASIO_TEST_CASE(posix_stream_descriptor_compile::test)
+  ASIO_COMPILE_TEST_CASE(posix_stream_descriptor_compile::test)
 )
