@@ -2,7 +2,7 @@
 // signal_set.cpp
 // ~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2016 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2022 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -17,7 +17,7 @@
 #include "asio/signal_set.hpp"
 
 #include "archetypes/async_result.hpp"
-#include "asio/io_service.hpp"
+#include "asio/io_context.hpp"
 #include "unit_test.hpp"
 
 //------------------------------------------------------------------------------
@@ -39,21 +39,27 @@ void test()
 
   try
   {
-    io_service ios;
+    io_context ioc;
+    const io_context::executor_type ioc_ex = ioc.get_executor();
     archetypes::lazy_handler lazy;
     asio::error_code ec;
 
     // basic_signal_set constructors.
 
-    signal_set set1(ios);
-    signal_set set2(ios, 1);
-    signal_set set3(ios, 1, 2);
-    signal_set set4(ios, 1, 2, 3);
+    signal_set set1(ioc);
+    signal_set set2(ioc, 1);
+    signal_set set3(ioc, 1, 2);
+    signal_set set4(ioc, 1, 2, 3);
+
+    signal_set set5(ioc_ex);
+    signal_set set6(ioc_ex, 1);
+    signal_set set7(ioc_ex, 1, 2);
+    signal_set set8(ioc_ex, 1, 2, 3);
 
     // basic_io_object functions.
 
-    io_service& ios_ref = set1.get_io_service();
-    (void)ios_ref;
+    signal_set::executor_type ex = set1.get_executor();
+    (void)ex;
 
     // basic_signal_set functions.
 
@@ -85,5 +91,5 @@ void test()
 ASIO_TEST_SUITE
 (
   "signal_set",
-  ASIO_TEST_CASE(signal_set_compile::test)
+  ASIO_COMPILE_TEST_CASE(signal_set_compile::test)
 )
