@@ -2,7 +2,7 @@
 // overlapped_ptr.cpp
 // ~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2020 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2022 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -115,5 +115,5 @@ void test()
 ASIO_TEST_SUITE
 (
   "windows/overlapped_ptr",
-  ASIO_TEST_CASE(windows_overlapped_ptr_compile::test)
+  ASIO_COMPILE_TEST_CASE(windows_overlapped_ptr_compile::test)
 )
