@@ -2,7 +2,7 @@
 // stream_handle.cpp
 // ~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2020 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2022 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -69,6 +69,9 @@ void test()
 
 #if defined(ASIO_HAS_MOVE)
     win::stream_handle handle5(std::move(handle4));
+
+    win::basic_stream_handle<io_context::executor_type> handle6(ioc);
+    win::stream_handle handle7(std::move(handle6));
 #endif // defined(ASIO_HAS_MOVE)
 
     // basic_stream_handle operators.
@@ -76,6 +79,7 @@ void test()
 #if defined(ASIO_HAS_MOVE)
     handle1 = win::stream_handle(ioc);
     handle1 = std::move(handle4);
+    handle1 = std::move(handle6);
 #endif // defined(ASIO_HAS_MOVE)
 
     // basic_io_object functions.
@@ -89,9 +93,9 @@ void test()
       = handle1.lowest_layer();
     (void)lowest_layer;
 
-    const win::stream_handle& handle6 = handle1;
+    const win::stream_handle& handle8 = handle1;
     const win::stream_handle::lowest_layer_type& lowest_layer2
-      = handle6.lowest_layer();
+      = handle8.lowest_layer();
     (void)lowest_layer2;
 
     HANDLE native_handle3 = INVALID_HANDLE_VALUE;
@@ -104,8 +108,15 @@ void test()
     handle1.close(ec);
 
     win::stream_handle::native_handle_type native_handle4
-      = handle1.native_handle();
+      = handle1.release();
     (void)native_handle4;
+    win::stream_handle::native_handle_type native_handle5
+      = handle1.release(ec);
+    (void)native_handle5;
+
+    win::stream_handle::native_handle_type native_handle6
+      = handle1.native_handle();
+    (void)native_handle6;
 
     handle1.cancel();
     handle1.cancel(ec);
@@ -144,5 +155,5 @@ void test()
 ASIO_TEST_SUITE
 (
   "windows/stream_handle",
-  ASIO_TEST_CASE(windows_stream_handle_compile::test)
+  ASIO_COMPILE_TEST_CASE(windows_stream_handle_compile::test)
 )
